==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/vo/CertifyReplaceBVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 证照替换申请-表体
 * 
 * @author generator
 * 
 */
public class CertifyReplaceBVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCertifreplace; // 主表主键
    private Long pkCorpcertifyF; // 证件配件详情主键
    private Long pkCertifreg; // 证照登记
    private Long pkCertiftype; // 证书类别
    private Long pkCertpsn; // 证书人员
    private String certifcode; // 证书编号
    private String jydate; // 申请日期
    private String isjyyj; // 原件/扫描件
    private String yjjcDate; // 原件借出日期
    private String isyyz; // 是否已押证
    private String isbjsuccess; // 是否报建成功
    private String sjghDate; // 实际归还日期
    private String isgh; // 是否已归还
    private String vmemo; // 备注
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 

    @ReferSerialTransfer(referCode = "certifyregH")
    public Long getPkCertifreg() {
        return pkCertifreg;
    }
    @ReferDeserialTransfer
    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Long getPkCertifreplace() {
        return pkCertifreplace;
    }

    public void setPkCertifreplace(Long pkCertifreplace) {
        this.pkCertifreplace = pkCertifreplace;
    }

    public Long getPkCorpcertifyF() {
        return pkCorpcertifyF;
    }

    public void setPkCorpcertifyF(Long pkCorpcertifyF) {
        this.pkCorpcertifyF = pkCorpcertifyF;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }
    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkCertpsn() {
        return pkCertpsn;
    }
    @ReferDeserialTransfer
    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }
    public String getSjghDate() {
        return sjghDate;
    }

    public void setSjghDate(String sjghDate) {
        this.sjghDate = sjghDate;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220616.071707-59-sources.jar: com/ejianc/certify/vo/CertifyReplaceBVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 证照替换申请-表体
 * 
 * @author generator
 * 
 */
public class CertifyReplaceBVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCertifreplace; // 主表主键
    private Long pkCorpcertifyF; // 证件配件详情主键
    private Long pkCertifreg; // 证照登记
    private Long pkCertiftype; // 证书类别
    private Long pkCertpsn; // 证书人员
    private String certifcode; // 证书编号
    private String jydate; // 申请日期
    private String isjyyj; // 原件/扫描件
    private String yjjcDate; // 原件借出日期
    private String isyyz; // 是否已押证
    private String isbjsuccess; // 是否报建成功
    private String sjghDate; // 实际归还日期
    private String isgh; // 是否已归还
    private String vmemo; // 备注
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; //
    private String isReplace;

    public String getIsReplace() {
        return isReplace;
    }

    public void setIsReplace(String isReplace) {
        this.isReplace = isReplace;
    }

    @ReferSerialTransfer(referCode = "certifyregH")
    public Long getPkCertifreg() {
        return pkCertifreg;
    }
    @ReferDeserialTransfer
    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Long getPkCertifreplace() {
        return pkCertifreplace;
    }

    public void setPkCertifreplace(Long pkCertifreplace) {
        this.pkCertifreplace = pkCertifreplace;
    }

    public Long getPkCorpcertifyF() {
        return pkCorpcertifyF;
    }

    public void setPkCorpcertifyF(Long pkCorpcertifyF) {
        this.pkCorpcertifyF = pkCorpcertifyF;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }
    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkCertpsn() {
        return pkCertpsn;
    }
    @ReferDeserialTransfer
    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }
    public String getSjghDate() {
        return sjghDate;
    }

    public void setSjghDate(String sjghDate) {
        this.sjghDate = sjghDate;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
